=======
CHANGES
=======

0.0.5
-----
- fixes in catalog/index template [zusel, fizyk]
- destination path added in translation_dirs as a translation source as well [fizyk]

0.0.4
-----
- fix issue with translation files path beeing not related to cwd [fizyk]

0.0.2
-----
- fixed MANIFEST.in [fizyk]

0.0.1
-----
- initial release [fizyk]
